@@ -12,8 +12,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #include "audio_device.h"
@@ -541,7 +540,6 @@ bool t_alsa_io::open(const string& device, bool playback, bool capture, bool blo
 	// Note: The buffersize is in FRAMES, not BYTES (one frame = sizeof(sample) * channels)
 	snd_pcm_uframes_t buffersize;
 	unsigned int periods = 8; // Double buffering
-	int dir = 1;
 	
 	// Set the size of one period in samples
 	if (short_latency) {
@@ -554,7 +552,7 @@ bool t_alsa_io::open(const string& device, bool playback, bool capture, bool blo
 		buffersize = 1024;
 	}
 	if ((err = snd_pcm_hw_params_set_period_size_near (pcm_ptr, hw_params, 
-			&buffersize, &dir)) < 0) 
+			&buffersize, nullptr)) < 0)
 	{
 		HANDLE_ALSA_ERROR("snd_pcm_hw_params_set_period_size_near");
 	}
@@ -570,10 +568,9 @@ bool t_alsa_io::open(const string& device, bool playback, bool capture, bool blo
 		periods *= 4;
 	}
 	
-	dir = 1;
-	if ((err = snd_pcm_hw_params_set_periods(pcm_ptr, hw_params, periods, dir)) < 0) {
+	if ((err = snd_pcm_hw_params_set_periods(pcm_ptr, hw_params, periods, 1)) < 0) {
 		if ((err = snd_pcm_hw_params_set_periods_near(pcm_ptr, hw_params, 
-				&periods, &dir)) < 0) 
+				&periods, nullptr)) < 0)
 		{
 			HANDLE_ALSA_ERROR("snd_pcm_hw_params_set_periods");
 		}
