@@ -20,8 +20,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 #include "mphoneform.h"
 #include "twinkle_config.h"
@@ -55,6 +54,7 @@
 #include <QRegExp>
 #include <QValidator>
 #include <QSettings>
+#include <QRegExpValidator>
 #include "buddyform.h"
 #include "diamondcardprofileform.h"
 #include "osd.h"
@@ -971,7 +971,7 @@ void MphoneForm::updateRegStatus()
 	toolTip.append("</b><br>");
 	toolTip.append("<table>");
 	
-	// Count number of succesful and failed registrations.
+	// Count number of successful and failed registrations.
 	// Determine tool tip showing registration details for all users.
 	list<t_user *>user_list = phone->ref_users();
 	for (list<t_user *>::iterator i = user_list.begin(); i != user_list.end(); i++) {
